@@ -1,4 +1,5 @@
 import glob
+import re
 import json
 import os
 import shutil
@@ -47,6 +48,7 @@ class SparkPipelineFrameworkTestRunner:
         output_as_json_only: bool = True,
         apply_schema_to_output: bool = True,
         check_output: bool = True,
+        ignore_views_for_output: Optional[List[str]] = None,
     ) -> None:
         """
         Tests Spark Transformers without writing any code
@@ -72,6 +74,7 @@ class SparkPipelineFrameworkTestRunner:
         :param output_as_json_only: (Optional) if set to True then do not output as csv
         :param apply_schema_to_output: If true applies schema to output file
         :param check_output: if set, check the output of the test.  Otherwise don't check the output.
+        :param ignore_views_for_output: list of view names to ignore when writing output schema and output json
         :return: Throws SparkPipelineFrameworkTestingException if there are mismatches between
                     expected output files and actual output files.  The `exceptions` list in
                     SparkPipelineFrameworkTestingException holds all the mismatch exceptions
@@ -155,6 +158,13 @@ class SparkPipelineFrameworkTestRunner:
                 # write out any missing schemas
                 output_tables: List[Table] = spark_session.catalog.listTables("default")
 
+                if ignore_views_for_output is not None:
+                    output_tables = [
+                        table
+                        for table in output_tables
+                        if table.name not in ignore_views_for_output
+                    ]
+
                 output_schema_folder: Path = Path(testable_folder).joinpath(
                     "output_schema"
                 )
@@ -568,7 +578,8 @@ class SparkPipelineFrameworkTestRunner:
     def get_view_name_from_file_path(input_file: str) -> str:
         view_name: str
         view_name, _ = os.path.splitext(PurePath(input_file).name)
-        return view_name
+        cleaned_view_name = re.sub(r"-", "_", view_name)
+        return cleaned_view_name
 
     @staticmethod
     def get_file_extension_from_file_path(file_name: str) -> str:
